oidc-register
=============

`OpenID Connect <https://openid.net/connect/>`_ Dynamic Client Registration tool.

.. image:: https://img.shields.io/pypi/v/oidc-register.svg?style=flat
  :target: https://pypi.python.org/pypi/oidc-register

This utility should work with any standards compliant OpenID Connect provider.

It has been tested with:

* `Ipsilon <https://ipsilon-project.org/>`_
